==> google-cloud-datastore-2.8.2.tar.gz: google-cloud-datastore-2.8.2/google/cloud/datastore_v1/types/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .datastore import (
    AllocateIdsRequest,
    AllocateIdsResponse,
    BeginTransactionRequest,
    BeginTransactionResponse,
    CommitRequest,
    CommitResponse,
    LookupRequest,
    LookupResponse,
    Mutation,
    MutationResult,
    ReadOptions,
    ReserveIdsRequest,
    ReserveIdsResponse,
    RollbackRequest,
    RollbackResponse,
    RunQueryRequest,
    RunQueryResponse,
    TransactionOptions,
)
from .entity import (
    ArrayValue,
    Entity,
    Key,
    PartitionId,
    Value,
)
from .query import (
    CompositeFilter,
    EntityResult,
    Filter,
    GqlQuery,
    GqlQueryParameter,
    KindExpression,
    Projection,
    PropertyFilter,
    PropertyOrder,
    PropertyReference,
    Query,
    QueryResultBatch,
)

__all__ = (
    "AllocateIdsRequest",
    "AllocateIdsResponse",
    "BeginTransactionRequest",
    "BeginTransactionResponse",
    "CommitRequest",
    "CommitResponse",
    "LookupRequest",
    "LookupResponse",
    "Mutation",
    "MutationResult",
    "ReadOptions",
    "ReserveIdsRequest",
    "ReserveIdsResponse",
    "RollbackRequest",
    "RollbackResponse",
    "RunQueryRequest",
    "RunQueryResponse",
    "TransactionOptions",
    "ArrayValue",
    "Entity",
    "Key",
    "PartitionId",
    "Value",
    "CompositeFilter",
    "EntityResult",
    "Filter",
    "GqlQuery",
    "GqlQueryParameter",
    "KindExpression",
    "Projection",
    "PropertyFilter",
    "PropertyOrder",
    "PropertyReference",
    "Query",
    "QueryResultBatch",
)

==> google-cloud-datastore-2.15.1.tar.gz: google-cloud-datastore-2.15.1/google/cloud/datastore_v1/types/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .aggregation_result import (
    AggregationResult,
    AggregationResultBatch,
)
from .datastore import (
    AllocateIdsRequest,
    AllocateIdsResponse,
    BeginTransactionRequest,
    BeginTransactionResponse,
    CommitRequest,
    CommitResponse,
    LookupRequest,
    LookupResponse,
    Mutation,
    MutationResult,
    ReadOptions,
    ReserveIdsRequest,
    ReserveIdsResponse,
    RollbackRequest,
    RollbackResponse,
    RunAggregationQueryRequest,
    RunAggregationQueryResponse,
    RunQueryRequest,
    RunQueryResponse,
    TransactionOptions,
)
from .entity import (
    ArrayValue,
    Entity,
    Key,
    PartitionId,
    Value,
)
from .query import (
    AggregationQuery,
    CompositeFilter,
    EntityResult,
    Filter,
    GqlQuery,
    GqlQueryParameter,
    KindExpression,
    Projection,
    PropertyFilter,
    PropertyOrder,
    PropertyReference,
    Query,
    QueryResultBatch,
)

__all__ = (
    "AggregationResult",
    "AggregationResultBatch",
    "AllocateIdsRequest",
    "AllocateIdsResponse",
    "BeginTransactionRequest",
    "BeginTransactionResponse",
    "CommitRequest",
    "CommitResponse",
    "LookupRequest",
    "LookupResponse",
    "Mutation",
    "MutationResult",
    "ReadOptions",
    "ReserveIdsRequest",
    "ReserveIdsResponse",
    "RollbackRequest",
    "RollbackResponse",
    "RunAggregationQueryRequest",
    "RunAggregationQueryResponse",
    "RunQueryRequest",
    "RunQueryResponse",
    "TransactionOptions",
    "ArrayValue",
    "Entity",
    "Key",
    "PartitionId",
    "Value",
    "AggregationQuery",
    "CompositeFilter",
    "EntityResult",
    "Filter",
    "GqlQuery",
    "GqlQueryParameter",
    "KindExpression",
    "Projection",
    "PropertyFilter",
    "PropertyOrder",
    "PropertyReference",
    "Query",
    "QueryResultBatch",
)
